/**
 * Copyright (c) 2011-2013, ReXSL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the ReXSL.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rexsl.maven.utils;

import com.jcabi.aspects.Loggable;
import javax.validation.constraints.NotNull;

/**
 * Logging configuration aware.Manages logging to alternate appenders depending
 * on scope/subscope at runtime.
 *
 * @author Evgeniy Nyavro (e.nyavro@gmail.com)
 * @version $Id: LoggingManager.java 2376 2013-03-08 09:08:56Z guard $
 * @todo #342 Implement appender scope change
 */
public final class LoggingManager {

    /**
     * Private ctor to prevent instance creation.
     */
    private LoggingManager() {
        // intentionally empty
    }

    /**
     * Enters logging scope.
     * If additional appender configured, method should set appender's new
     * output filename and apply changes
     * @param name Scope name.
     */
    @Loggable(Loggable.DEBUG)
    public static void enter(@NotNull final String name) {
        // intentionally empty
    }

    /**
     * Leaves scope if any presents.
     * If additional appender configured and the scope is entered, method
     * should pop the last scope, and restore previous appender filename
     */
    @Loggable(Loggable.DEBUG)
    public static void leave() {
        // intentionally empty
    }
}
